/*
 * Copyright (C) 2002 Andriy Palamarchuk
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __WINE_RICHOLE_H
#define __WINE_RICHOLE_H

#ifdef __cplusplus
extern "C" {
#endif

/* REOBJECT structure flags */
#define REO_GETOBJ_NO_INTERFACES        0x00000000
#define REO_GETOBJ_POLEOBJ              0x00000001
#define REO_GETOBJ_PSTG                 0x00000002
#define REO_GETOBJ_POLESITE             0x00000004
#define REO_GETOBJ_ALL_INTERFACES       0x00000007
#define REO_CP_SELECTION                0xFFFFFFFF
#define REO_IOB_SELECTION               0xFFFFFFFF
#define REO_IOB_USE_CP                  0xFFFFFFFE
#define REO_NULL                        0x00000000
#define REO_READWRITEMASK               0x0000003F
#define REO_DONTNEEDPALETTE             0x00000020
#define REO_BLANK                       0x00000010
#define REO_DYNAMICSIZE                 0x00000008
#define REO_INVERTEDSELECT              0x00000004
#define REO_BELOWBASELINE               0x00000002
#define REO_RESIZABLE                   0x00000001
#define REO_LINK                        0x80000000
#define REO_STATIC                      0x40000000
#define REO_SELECTED                    0x08000000
#define REO_OPEN                        0x04000000
#define REO_INPLACEACTIVE               0x02000000
#define REO_HILITED                     0x01000000
#define REO_LINKAVAILABLE               0x00800000
#define REO_GETMETAFILE                 0x00400000

/* clipboard operation flags */
#define RECO_PASTE            0x00000000
#define RECO_DROP             0x00000001
#define RECO_COPY             0x00000002
#define RECO_CUT              0x00000003
#define RECO_DRAG             0x00000004

#ifdef __cplusplus
}
#endif

typedef struct IRichEditOle IRichEditOle;

typedef struct _reobject {
    DWORD cbStruct;
    LONG cp;
    CLSID clsid;
    LPOLEOBJECT poleobj;
    LPSTORAGE pstg;
    LPOLECLIENTSITE polesite;
    SIZEL sizel;
    DWORD dvaspect;
    DWORD dwFlags;
    DWORD dwUser;
} REOBJECT;

#define INTERFACE IRichEditOle
#define IRichEditOle_METHODS \
    IUnknown_METHODS \
    STDMETHOD(GetClientSite)(THIS_ LPOLECLIENTSITE *) PURE; \
    STDMETHOD(GetObjectCount)(THIS) PURE; \
    STDMETHOD(GetLinkCount)(THIS) PURE; \
    STDMETHOD(GetObject)(THIS_ LONG, REOBJECT *, DWORD) PURE; \
    STDMETHOD(InsertObject)(THIS_ REOBJECT *) PURE; \
    STDMETHOD(ConvertObject)(THIS_ LONG, REFCLSID, LPCSTR) PURE; \
    STDMETHOD(ActivateAs)(THIS_ REFCLSID, REFCLSID) PURE; \
    STDMETHOD(SetHostNames)(THIS_ LPCSTR, LPCSTR) PURE; \
    STDMETHOD(SetLinkAvailable)(THIS_ LONG, BOOL) PURE; \
    STDMETHOD(SetDvaspect)(THIS_ LONG, DWORD) PURE; \
    STDMETHOD(HandsOffStorage)(THIS_ LONG) PURE; \
    STDMETHOD(SaveCompleted)(THIS_ LONG, LPSTORAGE) PURE; \
    STDMETHOD(InPlaceDeactivate)(THIS) PURE; \
    STDMETHOD(ContextSensitiveHelp)(THIS_ BOOL) PURE; \
    STDMETHOD(GetClipboardData)(THIS_ CHARRANGE*,DWORD,LPDATAOBJECT *) PURE; \
    STDMETHOD(ImportDataObject)(THIS_ LPDATAOBJECT, CLIPFORMAT, HGLOBAL) PURE;
ICOM_DEFINE(IRichEditOle,IUnknown)
#undef INTERFACE

#ifdef COBJMACROS
/* IUnknown Methods */
#define IRichEditOle_QueryInterface(p,a,b)  (p)->lpVtbl->QueryInterface(p,a,b)
#define IRichEditOle_AddRef(p)              (p)->lpVtbl->AddRef(p)
#define IRichEditOle_Release(p)             (p)->lpVtbl->Release(p)
/* IRichEditOle Methods */
#define IRichEditOle_ActivateAs(p,a,b)      (p)->lpVtbl->ActivateAs(p,a,b)
#define IRichEditOle_ContextSensitiveHelp(p,a) (p)->lpVtbl->ContextSensitiveHelp(p,a)
#define IRichEditOle_ConvertObject(p,a,b,c) (p)->lpVtbl->ConvertObject(p,a,b,c)
#define IRichEditOle_GetClientSite(p,a)     (p)->lpVtbl->GetClientSite(p,a)
#define IRichEditOle_GetClipboardData(p,a,b,c) (p)->lpVtbl->GetClipboardData(p,a,b,c)
#define IRichEditOle_GetLinkCount(p)        (p)->lpVtbl->GetLinkCount(p)
#define IRichEditOle_GetObject(p,a,b,c)     (p)->lpVtbl->GetObject(p,a,b,c)
#define IRichEditOle_GetObjectCount(p)      (p)->lpVtbl->GetObjectCount(p)
#define IRichEditOle_HandsOffStorage(p,a)   (p)->lpVtbl->HandsOffStorage(p,a)
#define IRichEditOle_ImportDataObject(p,a,b,c) (p)->lpVtbl->ImportDataObject(p,a,b,c)
#define IRichEditOle_InPlaceDeactivate(p)   (p)->lpVtbl->InPlaceDeactivate(p)
#define IRichEditOle_InsertObject(p,a)      (p)->lpVtbl->InsertObject(p,a)
#define IRichEditOle_SaveCompleted(p,a,b)   (p)->lpVtbl->SaveCompleted(p,a,b)
#define IRichEditOle_SetDvaspect(p,a,b)     (p)->lpVtbl->SetDvaspect(p,a,b)
#define IRichEditOle_SetHostNames(p,a,b)    (p)->lpVtbl->SetHostNames(p,a,b)
#define IRichEditOle_SetLinkAvailable(p,a,b) (p)->lpVtble->SetLinkAvailable(p,a,b)
#endif

#endif /* __WINE_RICHOLE_H */
